MethodChannelHardwareBarcodeScanner class

Default scanner platform implementation backed by Flutter channels.

Inheritance

Constructors

MethodChannelHardwareBarcodeScanner({@visibleForTesting bool? isWeb})
Creates the default platform implementation.

Properties

broadcastScans Stream<Map<String, Object?>>
Native broadcast scan events converted to string-keyed maps.
no setteroverride
eventChannel EventChannel
Channel that delivers native scanner broadcasts.
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
Channel used to start and stop the native scanner integration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startAndroidBroadcasts({required List<AndroidScannerBroadcastPreset> presets, bool configureChainwayBroadcastOutput = true, bool showLogs = false}) Future<void>
Starts the native Android receiver with the supplied presets.
override
stopAndroidBroadcasts() Future<void>
Stops the native Android broadcast receiver.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited