methodChannel property
Channel used to start and stop the native scanner integration.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('hardware_barcode_scanner/methods');
Channel used to start and stop the native scanner integration.
@visibleForTesting
final methodChannel = const MethodChannel('hardware_barcode_scanner/methods');