HardwareBarcodeScannerPlatform class abstract
Contract implemented by platform-specific scanner integrations.
- Inheritance
-
- Object
- PlatformInterface
- HardwareBarcodeScannerPlatform
- Implementers
Constructors
- HardwareBarcodeScannerPlatform()
- Creates a platform implementation with token verification enabled.
Properties
-
broadcastScans
→ Stream<
Map< String, Object?> > -
Native scanner events received from Android broadcast intents.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startAndroidBroadcasts(
{required List< AndroidScannerBroadcastPreset> presets, bool configureChainwayBroadcastOutput = true, bool showLogs = false}) → Future<void> -
Registers Android broadcast actions from
presets. -
stopAndroidBroadcasts(
) → Future< void> - Unregisters Android scanner broadcasts and closes optional vendor output.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ HardwareBarcodeScannerPlatform
-
The active platform implementation.
getter/setter pair